module Main where

import Hkl.Projects

main :: IO ()
main = charlier
  -- irdrx
  -- martinetto'
  -- melle
  -- d2am
  -- charlier
  -- laure
  -- hercules
  -- hamon
  -- schlegel
  -- romeden
